from .__version__ import __version__
from .HowFairIsChecker import HowFairIsChecker


__author__ = "https://github.com/jspaaks"
__email__ = 'j.spaaks@esciencecenter.nl'

__all__ = [
    "__version__",
    "HowFairIsChecker"
]
